.. _evrm:

.. image:: ../jpg/nederland2.jpg
    :width: 100%
    :height: 4cm

EVRM
####

| In 2012 heb ik het Europeese Hof voor de Rechten van de Mens :ref:`aangeschreven <verzoek>` om een klacht tegen Nederland in te dienen.
| De :ref:`klacht <greffe>` betrof het afwezig zijn van verpleging in het nieuwe ambulante behandeltijdperk van de GGZ.
| :ref:`Uitspraak <uitspraak>` is niet-ontvankelijk. 

| Het EVRM is voor de GGZ patient een doodlopende weg.

| Het is pas na tussenkomst van de koningin mogelijk om :ref:`aangifte <aangifte>` te kunnen.
| De :ref:`Hoge Raad <hogeraad>` concludeert dat het geen verantwoordelijkheid heeft.
| Het verwijst vervolgens naar het :ref:`IGZ <om>`, die geen structurele :ref:`onzorgvuldigheid <igz>` in de afhandeling van klachten bij GGZ-NHN constrateert.
| De IGZ heeft erkent verantwoordelijk te zijn voor ambulante zorg, zowel voor vrijwillig als onder de BOPZ behandelde patienten, zie :ref:`quote <absoluut>`.

| De GGZ patient als slachtoffer word de rechtsgang naar de strafrechter geblokkeerd.

| De :ref:`Minister van VWS <minister>` zegt dat de wijze waarop hulp word geboden levert een bijdrage aan het voorkomen van een (dwang)opname in een ggz-instelling.
| Het is niet mogelijk voor de Koningin, noch de Koning om  :ref:`verdere tussenkomst <beuker>` te verlenen vanwege ministeriele verantwoordelijkheid. 

| Op basis van de veronderstelling dat opnames worden voorkomen is men bedden gaan afbouwen.
